@@ -14,7 +14,7 @@ fn main() {
 
     let mut ttlv_hex_str = std::fs::read_to_string(&args[1]).expect("Failed to read the input file");
 
-    for string_to_remove in [" ", "\n", r#"""#, ","] {
+    for string_to_remove in &[" ", "\n", r#"""#, ","] {
         ttlv_hex_str = ttlv_hex_str.replace(string_to_remove, "");
     }
 
